# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`dconf`](#dconf): Installs and configures dconf

### Defined types

* [`dconf::db`](#dconfdb): Create dconf db keyfiles
* [`dconf::profile`](#dconfprofile): Create dconf profiles

## Classes

### <a name="dconf"></a>`dconf`

Installs and configures dconf

#### Examples

##### Declaring the class

```puppet
include dconf
```

#### Parameters

The following parameters are available in the `dconf` class:

* [`manage_packages`](#manage_packages)
* [`packages`](#packages)
* [`profiles`](#profiles)
* [`dbs`](#dbs)

##### <a name="manage_packages"></a>`manage_packages`

Data type: `Boolean`

Whether to manage the dconf packages.

Default value: ``true``

##### <a name="packages"></a>`packages`

Data type: `Array`

The packages required for dconf management. Typically sourced via hiera.

Default value: `[]`

##### <a name="profiles"></a>`profiles`

Data type: `Optional[Hash]`

Hash of dconf profiles

Default value: ``undef``

##### <a name="dbs"></a>`dbs`

Data type: `Optional[Hash]`

Hash of dconf databases, settings and locks

Default value: ``undef``

## Defined types

### <a name="dconfdb"></a>`dconf::db`

Create dconf db keyfiles

#### Examples

##### Create a dconf db keyfile with given settings

```puppet
dconf::db { 'local':
  settings => {
    'system/proxy/http' => {
      'host' => "'172.16.0.1'",
      'enabled' => 'true',
    },
    'org/gnome/desktop/background' => {
      'picture-uri' => 'file:///usr/local/rupert-corp/company-wallpaper.jpeg',
    },
  },
}
```

##### Lockdown dconf settings

```puppet
dconf::db { 'local':
  settings => {
    'system/proxy/http' => {
      'host' => "'172.16.0.1'",
      'enabled' => 'true',
    },
  locks => [
    'system/proxy/http/host',
    'system/proxy/http/enabled',
  ],
```

##### Managing multiple config files for the same db

```puppet
dconf::db { 'system-proxy':
  db_dir      => '/etc/dconf/db/local.d',
  db_filename => 'system-proxy',
  settings    => {
    'system/proxy/http' => {
      'host'    => "'172.16.0.1'",
      'enabled' => 'true',
    },
  },
}
dconf::db { 'disable-microphone':
  db_dir      => '/etc/dconf/db/local.d',
  db_filename => 'disable-micrphone',
  settings    => {
    'org/gnome/desktop/privacy' => {
      'disable-microphone' => 'true',
    },
  },
}
```

#### Parameters

The following parameters are available in the `dconf::db` defined type:

* [`settings`](#settings)
* [`locks`](#locks)
* [`base_dir`](#base_dir)
* [`db_dir`](#db_dir)
* [`db_filename`](#db_filename)
* [`db_file`](#db_file)
* [`locks_dir`](#locks_dir)
* [`locks_filename`](#locks_filename)
* [`locks_file`](#locks_file)
* [`base_dir_mode`](#base_dir_mode)
* [`db_dir_mode`](#db_dir_mode)
* [`db_file_mode`](#db_file_mode)
* [`locks_dir_mode`](#locks_dir_mode)
* [`locks_file_mode`](#locks_file_mode)
* [`purge`](#purge)
* [`ensure`](#ensure)
* [`inifile_defaults`](#inifile_defaults)

##### <a name="settings"></a>`settings`

Data type: `Optional[Hash]`

Hash of dconf settings

Default value: ``undef``

##### <a name="locks"></a>`locks`

Data type: `Optional[Array]`

Array of dconf settings to lock

Default value: ``undef``

##### <a name="base_dir"></a>`base_dir`

Data type: `Stdlib::Absolutepath`

Absolute path of the dconf db base directory

Default value: `'/etc/dconf/db'`

##### <a name="db_dir"></a>`db_dir`

Data type: `Stdlib::Absolutepath`

Absolute path of the dconf db directory

Default value: `"${base_dir}/${name}.d"`

##### <a name="db_filename"></a>`db_filename`

Data type: `String`

Name of the dconf db file

Default value: `'00-default'`

##### <a name="db_file"></a>`db_file`

Data type: `Stdlib::Absolutepath`

Absolute path of the dconf db file

Default value: `"${db_dir}/${db_filename}"`

##### <a name="locks_dir"></a>`locks_dir`

Data type: `Stdlib::Absolutepath`

Absolute path of the dconf db locks directory

Default value: `"${db_dir}/locks"`

##### <a name="locks_filename"></a>`locks_filename`

Data type: `String`

Name of the dconf locks file

Default value: `'00-default'`

##### <a name="locks_file"></a>`locks_file`

Data type: `Stdlib::Absolutepath`

Absolute path of the dconf db locks file

Default value: `"${locks_dir}/${locks_filename}"`

##### <a name="base_dir_mode"></a>`base_dir_mode`

Data type: `String`

File permissions for dconf db base directory

Default value: `'0755'`

##### <a name="db_dir_mode"></a>`db_dir_mode`

Data type: `String`

File permissions for dconf db directory

Default value: `'0755'`

##### <a name="db_file_mode"></a>`db_file_mode`

Data type: `String`

File permissions for dconf db file

Default value: `'0644'`

##### <a name="locks_dir_mode"></a>`locks_dir_mode`

Data type: `String`

File permissions for dconf db locks directory

Default value: `'0755'`

##### <a name="locks_file_mode"></a>`locks_file_mode`

Data type: `String`

File permissions for dconf db locks file

Default value: `'0644'`

##### <a name="purge"></a>`purge`

Data type: `Boolean`

Whether to purge unmanaged files (keyfiles and lock files)

Default value: ``true``

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Whether to ensure presence or absence of the resource

Default value: `'present'`

##### <a name="inifile_defaults"></a>`inifile_defaults`

Data type: `Hash`

Default parameters to parse to inifile provider

Default value: `{ ensure => 'present', path => $db_file, notify => Exec['dconf_update'], require => File[$db_file], }`

### <a name="dconfprofile"></a>`dconf::profile`

Create dconf profiles

#### Examples

##### Creating dconf profiles

```puppet
dconf::profile { 'local':
  entries => {
    'user' => {
      'type'  => 'user',
      'order' => 10,
     },
    'local' => {
      'type'  => 'system',
      'order' => 21,
    },
    'site' => {
      'type'  => 'system',
      'order' => 21,
    },
  },
}
```

#### Parameters

The following parameters are available in the `dconf::profile` defined type:

* [`profile_dir`](#profile_dir)
* [`profile_file`](#profile_file)
* [`profile_dir_mode`](#profile_dir_mode)
* [`profile_file_mode`](#profile_file_mode)
* [`purge`](#purge)
* [`ensure`](#ensure)
* [`default_entry_order`](#default_entry_order)
* [`entries`](#entries)

##### <a name="profile_dir"></a>`profile_dir`

Data type: `Stdlib::Absolutepath`

Absolute path to dconf profile directory

Default value: `'/etc/dconf/profile'`

##### <a name="profile_file"></a>`profile_file`

Data type: `Stdlib::Absolutepath`

Absolute path to dconf profile file

Default value: `"${profile_dir}/${name}"`

##### <a name="profile_dir_mode"></a>`profile_dir_mode`

Data type: `String`

File permissions for dconf profile directory

Default value: `'0755'`

##### <a name="profile_file_mode"></a>`profile_file_mode`

Data type: `String`

File permissions for dconf profile file

Default value: `'0644'`

##### <a name="purge"></a>`purge`

Data type: `Boolean`

Control whether to purge the dconf profile directory of unmanaged files

Default value: ``false``

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Whether to ensure presence or absence of the dconf profile

Default value: `'present'`

##### <a name="default_entry_order"></a>`default_entry_order`

Data type: `String`

Default order of profile entries

Default value: `'25'`

##### <a name="entries"></a>`entries`

Data type: `Optional[Hash]`

List of entries to include in the dconf profile

Default value: ``undef``

